@@ -66,7 +66,7 @@ their Python 3 names and locations::
     import configparser
     import test.support
     from collections import UserList
-    from itertools import filterfalse
+    from itertools import filterfalse, zip_longest
     # and other moved modules and definitions
 
 It also includes backports for these stdlib packages from Py3 that were
@@ -172,7 +172,7 @@ else:
 
 __ver_major__ = 0
 __ver_minor__ = 3
-__ver_patch__ = 3
+__ver_patch__ = 4
 __ver_sub__ = ''
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,__ver_patch__,__ver_sub__)
 
