@@ -5,11 +5,10 @@ with the future module using:
 
     from future import *
 
-It contains tests that perform a scripted porting process using 2to3.
-(and in the future also python-modernize). It then tests whether the
-resulting Python 2/3 code (python-modernize) or Python 3 code (from 2to3)
-is able to run under Python 2 using the relevant ``future`` module
-imports.
+It contains tests that perform a scripted porting process using
+python-futurize. It then tests whether the resulting Python 2/3 code
+is indeed able to run under Python 3 and under Python 2 using the
+relevant ``future`` module imports.
 """
 
 from __future__ import print_function, absolute_import
@@ -17,12 +16,18 @@ from __future__ import print_function, absolute_import
 import unittest
 import textwrap
 import pprint
-from subprocess import Popen, PIPE, check_output, STDOUT
+from subprocess import Popen, PIPE
+import tempfile
+import os
+
+from future.tests.base import CodeHandler
 
 
-class Test2to3Simple(unittest.TestCase):
+class Test2to3Simple(CodeHandler, unittest.TestCase):
     def setUp(self):
         self.interpreter = 'python'
+        self.tempdir = tempfile.mkdtemp() + os.path.sep
+        self.env = {'PYTHONPATH': os.getcwd()}
 
     def test_xrange(self):
         code = '''
@@ -32,8 +37,11 @@ class Test2to3Simple(unittest.TestCase):
         self.simple_convert_and_check(code)
 
     def test_range_slice(self):
+        """
+        This should run on Py2 without a MemoryError
+        """
         code = '''
-        for i in range(10**11)[:10]:
+        for i in range(10**15)[:10]:
             pass
         '''
         self.simple_convert_and_check(code)
@@ -48,7 +56,7 @@ class Test2to3Simple(unittest.TestCase):
                 print 'Adding an item'
                 super(VerboseList, self).append(item)
         '''
-        self.simple_convert_and_check(code, fixers=['print'])
+        self.simple_convert_and_check(code)
 
     def test_apply(self):
         code = '''
@@ -57,7 +65,7 @@ class Test2to3Simple(unittest.TestCase):
         
         assert apply(addup, (10,20)) == 30
         '''
-        self.simple_convert_and_check(code, fixers=['apply'])
+        self.simple_convert_and_check(code)
     
     def test_renamed_modules(self):
         code = '''
@@ -66,9 +74,9 @@ class Test2to3Simple(unittest.TestCase):
         import cPickle
         import cStringIO
         '''
-        self.simple_convert_and_check(code, fixers=['imports'])
+        self.simple_convert_and_check(code)
     
-    def simple_convert_and_check(self, code, fixers=['all']):
+    def simple_convert_and_check(self, code):
         """
         Tests a complete conversion of this simple piece of code from the
         docs here:
@@ -77,21 +85,9 @@ class Test2to3Simple(unittest.TestCase):
         automatically run under Python 2 with the future module.
         """
         # Translate the clean source file, then add our imports
-        with open('mytestscript.py', 'w') as f:
-            f.write(textwrap.dedent(code))
-        output = check_output(['2to3', 'mytestscript.py', '-w', '-f'] + fixers,
-                              stderr=STDOUT)
-        # print(output)
-        # Read the translated file and add our imports
-        with open('mytestscript.py') as f:
-            newsource = f.read()
-        with open('mytestscript.py', 'w') as f:
-            f.write('from __future__ import print_function, absolute_import, division, unicode_literals\n')
-            f.write('from future import *\n')
-            f.write('from future import standard_library\n')
-            f.write(newsource)
-
-        output2 = check_output([self.interpreter, 'mytestscript.py'])
+        self._write_test_script(code)
+        self._futurize_test_script()
+        output2 = self._run_test_script()
         print(output2)
 
     @unittest.skip('not implemented yet')
@@ -117,9 +113,10 @@ class Test2to3Simple(unittest.TestCase):
 
     def test_raw_input(self):
         """
-        Passes in a string to the waiting input() after 2to3 conversion
+        Passes in a string to the waiting input() after python-futurize
+        conversion.
         """
-        code = '''
+        py2code = '''
         from future import *
         def greet(name):
             print "Hello, {0}!".format(name)
@@ -127,16 +124,15 @@ class Test2to3Simple(unittest.TestCase):
         name = raw_input()
         greet(name)
         '''
-        with open('mytestscript.py', 'w') as f:
-            f.write(textwrap.dedent(code))
-        output = check_output(['2to3', 'mytestscript.py', '-w'],
-                              stderr=STDOUT)
+        self._write_test_script(py2code)
+        output = self._futurize_test_script()
         # print(output)
-        p1 = Popen([self.interpreter, 'mytestscript.py'],
-                   stdout=PIPE, stdin=PIPE)
+
+        p1 = Popen([self.interpreter, self.tempdir + 'mytestscript.py'],
+                   stdout=PIPE, stdin=PIPE, stderr=PIPE, env=self.env)
         (stdout, stderr) = p1.communicate(b'Ed')
         print(stdout)
-        #print(stderr)
+        print(stderr)
         self.assertEqual(stdout, b"What's your name?\nHello, Ed!\n")
 
         
